==> jc-1.4.0.tar.gz: soot/dava/toolkits/base/finders/SwitchFinder.h <==
// public class soot.dava.toolkits.base.finders.SwitchFinder

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 3813d6dcf7860add soot_dava_toolkits_base_finders_SwitchFinder

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_dava_toolkits_base_finders_SwitchFinder_H_
#define _JC_soot_dava_toolkits_base_finders_SwitchFinder_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_util_HashMap$object;
struct _jc_java_util_HashSet$object;
struct _jc_java_util_LinkedList$object;
struct _jc_soot_Singletons__24Global$object;
struct _jc_soot_dava_DavaBody$object;
struct _jc_soot_dava_internal_SET_SETNode$object;
struct _jc_soot_dava_internal_asg_AugmentedStmt$object;
struct _jc_soot_dava_internal_asg_AugmentedStmtGraph$object;
struct _jc_soot_dava_toolkits_base_finders_SwitchFinder$object;
struct _jc_soot_util_IterableSet$object;

// Typedefs
typedef struct _jc_soot_dava_toolkits_base_finders_SwitchFinder$sub_refs	_jc_soot_dava_toolkits_base_finders_SwitchFinder$sub_refs;
typedef struct _jc_soot_dava_toolkits_base_finders_SwitchFinder$sub_nonrefs	_jc_soot_dava_toolkits_base_finders_SwitchFinder$sub_nonrefs;
typedef struct _jc_soot_dava_toolkits_base_finders_SwitchFinder$refs	_jc_soot_dava_toolkits_base_finders_SwitchFinder$refs;
typedef struct _jc_soot_dava_toolkits_base_finders_SwitchFinder$nonrefs	_jc_soot_dava_toolkits_base_finders_SwitchFinder$nonrefs;
typedef struct _jc_soot_dava_toolkits_base_finders_SwitchFinder$object	_jc_soot_dava_toolkits_base_finders_SwitchFinder$object;

typedef const struct _jc_soot_dava_toolkits_base_finders_SwitchFinder$vmethods	_jc_soot_dava_toolkits_base_finders_SwitchFinder$vmethods;
typedef const struct _jc_soot_dava_toolkits_base_finders_SwitchFinder$vtable	_jc_soot_dava_toolkits_base_finders_SwitchFinder$vtable;
typedef const struct _jc_soot_dava_toolkits_base_finders_SwitchFinder$vtype	_jc_soot_dava_toolkits_base_finders_SwitchFinder$vtype;

// Constructors
extern void _jc_soot_dava_toolkits_base_finders_SwitchFinder$method$_init$bbe94f634b20986f(_jc_env *, struct _jc_soot_dava_toolkits_base_finders_SwitchFinder$object *, struct _jc_soot_Singletons__24Global$object *);

// Virtual methods
extern void _jc_soot_dava_toolkits_base_finders_SwitchFinder$method$build__5fBindings$7f27d5c6d4063a7d(_jc_env *, struct _jc_soot_dava_toolkits_base_finders_SwitchFinder$object *, struct _jc_soot_dava_internal_asg_AugmentedStmt$object *, struct _jc_java_lang_Object$object *, struct _jc_soot_dava_internal_asg_AugmentedStmt$object *);
extern void _jc_soot_dava_toolkits_base_finders_SwitchFinder$method$find$6aba89b6167e2073(_jc_env *, struct _jc_soot_dava_toolkits_base_finders_SwitchFinder$object *, struct _jc_soot_dava_DavaBody$object *, struct _jc_soot_dava_internal_asg_AugmentedStmtGraph$object *, struct _jc_soot_dava_internal_SET_SETNode$object *);
extern struct _jc_soot_util_IterableSet$object *_jc_soot_dava_toolkits_base_finders_SwitchFinder$method$find__5fSubBody$df05fe43395b95d7(_jc_env *, struct _jc_soot_dava_toolkits_base_finders_SwitchFinder$object *, struct _jc_soot_dava_internal_asg_AugmentedStmt$object *, struct _jc_soot_dava_internal_asg_AugmentedStmt$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_dava_toolkits_base_finders_SwitchFinder$method_info$build__5fBindings$7f27d5c6d4063a7d;
extern _jc_method _jc_soot_dava_toolkits_base_finders_SwitchFinder$method_info$find$6aba89b6167e2073;
extern _jc_method _jc_soot_dava_toolkits_base_finders_SwitchFinder$method_info$find__5fSubBody$df05fe43395b95d7;

// Static methods
extern struct _jc_soot_dava_toolkits_base_finders_SwitchFinder$object *_jc_soot_dava_toolkits_base_finders_SwitchFinder$method$v$556f7eacdea89a19(_jc_env *);

// Virtual methods structure
struct _jc_soot_dava_toolkits_base_finders_SwitchFinder$vmethods {
	void	(*build__5fBindings$7f27d5c6d4063a7d)(_jc_env *, struct _jc_soot_dava_toolkits_base_finders_SwitchFinder$object *, struct _jc_soot_dava_internal_asg_AugmentedStmt$object *, struct _jc_java_lang_Object$object *, struct _jc_soot_dava_internal_asg_AugmentedStmt$object *);
	void	(*find$6aba89b6167e2073)(_jc_env *, struct _jc_soot_dava_toolkits_base_finders_SwitchFinder$object *, struct _jc_soot_dava_DavaBody$object *, struct _jc_soot_dava_internal_asg_AugmentedStmtGraph$object *, struct _jc_soot_dava_internal_SET_SETNode$object *);
	struct _jc_soot_util_IterableSet$object	*(*find__5fSubBody$df05fe43395b95d7)(_jc_env *, struct _jc_soot_dava_toolkits_base_finders_SwitchFinder$object *, struct _jc_soot_dava_internal_asg_AugmentedStmt$object *, struct _jc_soot_dava_internal_asg_AugmentedStmt$object *);
};

// Vtable
struct _jc_soot_dava_toolkits_base_finders_SwitchFinder$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_dava_toolkits_base_finders_SwitchFinder$vmethods	soot_dava_toolkits_base_finders_SwitchFinder;
};

// Vtype
struct _jc_soot_dava_toolkits_base_finders_SwitchFinder$vtype {
	_jc_type			type;
	_jc_soot_dava_toolkits_base_finders_SwitchFinder$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_dava_toolkits_base_finders_SwitchFinder$sub_refs {
	struct _jc_soot_util_IterableSet$object	*junkBody;
	struct _jc_java_util_HashSet$object	*targetSet;
	struct _jc_java_util_LinkedList$object	*targetList;
	struct _jc_java_util_LinkedList$object	*snTargetList;
	struct _jc_java_util_LinkedList$object	*tSuccList;
	struct _jc_java_util_HashMap$object	*index2target;
	struct _jc_java_util_HashMap$object	*tSucc2indexSet;
	struct _jc_java_util_HashMap$object	*tSucc2target;
	struct _jc_java_util_HashMap$object	*tSucc2Body;
};

// Reference instance fields (object)
struct _jc_soot_dava_toolkits_base_finders_SwitchFinder$refs {
    _jc_soot_dava_toolkits_base_finders_SwitchFinder$sub_refs	soot_dava_toolkits_base_finders_SwitchFinder;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_dava_toolkits_base_finders_SwitchFinder$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_dava_toolkits_base_finders_SwitchFinder$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_dava_toolkits_base_finders_SwitchFinder$sub_nonrefs	soot_dava_toolkits_base_finders_SwitchFinder;
};

// Object instance structure
struct _jc_soot_dava_toolkits_base_finders_SwitchFinder$object {
	_jc_soot_dava_toolkits_base_finders_SwitchFinder$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_dava_toolkits_base_finders_SwitchFinder$vtype	*vtype;
	_jc_soot_dava_toolkits_base_finders_SwitchFinder$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_dava_toolkits_base_finders_SwitchFinder$vtype _jc_soot_dava_toolkits_base_finders_SwitchFinder$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_dava_toolkits_base_finders_SwitchFinder, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_dava_toolkits_base_finders_SwitchFinder$class_object;

#endif	/* _JC_soot_dava_toolkits_base_finders_SwitchFinder_H_ */

==> jc-1.4.6.tar.gz: soot/dava/toolkits/base/finders/SwitchFinder.h <==
// public class soot.dava.toolkits.base.finders.SwitchFinder

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 3813d6dcf7860add soot_dava_toolkits_base_finders_SwitchFinder

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_dava_toolkits_base_finders_SwitchFinder_H_
#define _JC_soot_dava_toolkits_base_finders_SwitchFinder_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_util_HashMap$object;
struct _jc_java_util_HashSet$object;
struct _jc_java_util_LinkedList$object;
struct _jc_soot_Singletons__24Global$object;
struct _jc_soot_dava_DavaBody$object;
struct _jc_soot_dava_internal_SET_SETNode$object;
struct _jc_soot_dava_internal_asg_AugmentedStmt$object;
struct _jc_soot_dava_internal_asg_AugmentedStmtGraph$object;
struct _jc_soot_dava_toolkits_base_finders_SwitchFinder$object;
struct _jc_soot_util_IterableSet$object;

// Typedefs
typedef struct _jc_soot_dava_toolkits_base_finders_SwitchFinder$sub_refs	_jc_soot_dava_toolkits_base_finders_SwitchFinder$sub_refs;
typedef struct _jc_soot_dava_toolkits_base_finders_SwitchFinder$sub_nonrefs	_jc_soot_dava_toolkits_base_finders_SwitchFinder$sub_nonrefs;
typedef struct _jc_soot_dava_toolkits_base_finders_SwitchFinder$refs	_jc_soot_dava_toolkits_base_finders_SwitchFinder$refs;
typedef struct _jc_soot_dava_toolkits_base_finders_SwitchFinder$nonrefs	_jc_soot_dava_toolkits_base_finders_SwitchFinder$nonrefs;
typedef struct _jc_soot_dava_toolkits_base_finders_SwitchFinder$object	_jc_soot_dava_toolkits_base_finders_SwitchFinder$object;

typedef const struct _jc_soot_dava_toolkits_base_finders_SwitchFinder$vmethods	_jc_soot_dava_toolkits_base_finders_SwitchFinder$vmethods;
typedef const struct _jc_soot_dava_toolkits_base_finders_SwitchFinder$vtable	_jc_soot_dava_toolkits_base_finders_SwitchFinder$vtable;
typedef const struct _jc_soot_dava_toolkits_base_finders_SwitchFinder$vtype	_jc_soot_dava_toolkits_base_finders_SwitchFinder$vtype;

// Constructors
extern void _jc_soot_dava_toolkits_base_finders_SwitchFinder$method$_init$bbe94f634b20986f(_jc_env *, struct _jc_soot_dava_toolkits_base_finders_SwitchFinder$object *, struct _jc_soot_Singletons__24Global$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_dava_toolkits_base_finders_SwitchFinder$method$build__5fBindings$7f27d5c6d4063a7d(_jc_env *, struct _jc_soot_dava_toolkits_base_finders_SwitchFinder$object *, struct _jc_soot_dava_internal_asg_AugmentedStmt$object *, struct _jc_java_lang_Object$object *, struct _jc_soot_dava_internal_asg_AugmentedStmt$object *) _JC_JCNI_ATTR;
extern void _jc_soot_dava_toolkits_base_finders_SwitchFinder$method$find$6aba89b6167e2073(_jc_env *, struct _jc_soot_dava_toolkits_base_finders_SwitchFinder$object *, struct _jc_soot_dava_DavaBody$object *, struct _jc_soot_dava_internal_asg_AugmentedStmtGraph$object *, struct _jc_soot_dava_internal_SET_SETNode$object *) _JC_JCNI_ATTR;
extern struct _jc_soot_util_IterableSet$object *_jc_soot_dava_toolkits_base_finders_SwitchFinder$method$find__5fSubBody$df05fe43395b95d7(_jc_env *, struct _jc_soot_dava_toolkits_base_finders_SwitchFinder$object *, struct _jc_soot_dava_internal_asg_AugmentedStmt$object *, struct _jc_soot_dava_internal_asg_AugmentedStmt$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_dava_toolkits_base_finders_SwitchFinder$method_info$build__5fBindings$7f27d5c6d4063a7d;
extern _jc_method _jc_soot_dava_toolkits_base_finders_SwitchFinder$method_info$find$6aba89b6167e2073;
extern _jc_method _jc_soot_dava_toolkits_base_finders_SwitchFinder$method_info$find__5fSubBody$df05fe43395b95d7;

// Static methods
extern struct _jc_soot_dava_toolkits_base_finders_SwitchFinder$object *_jc_soot_dava_toolkits_base_finders_SwitchFinder$method$v$556f7eacdea89a19(_jc_env *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_soot_dava_toolkits_base_finders_SwitchFinder$vmethods {
	void	(*build__5fBindings$7f27d5c6d4063a7d)(_jc_env *, struct _jc_soot_dava_toolkits_base_finders_SwitchFinder$object *, struct _jc_soot_dava_internal_asg_AugmentedStmt$object *, struct _jc_java_lang_Object$object *, struct _jc_soot_dava_internal_asg_AugmentedStmt$object *) _JC_JCNI_ATTR;
	void	(*find$6aba89b6167e2073)(_jc_env *, struct _jc_soot_dava_toolkits_base_finders_SwitchFinder$object *, struct _jc_soot_dava_DavaBody$object *, struct _jc_soot_dava_internal_asg_AugmentedStmtGraph$object *, struct _jc_soot_dava_internal_SET_SETNode$object *) _JC_JCNI_ATTR;
	struct _jc_soot_util_IterableSet$object	*(*find__5fSubBody$df05fe43395b95d7)(_jc_env *, struct _jc_soot_dava_toolkits_base_finders_SwitchFinder$object *, struct _jc_soot_dava_internal_asg_AugmentedStmt$object *, struct _jc_soot_dava_internal_asg_AugmentedStmt$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_dava_toolkits_base_finders_SwitchFinder$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_dava_toolkits_base_finders_SwitchFinder$vmethods	soot_dava_toolkits_base_finders_SwitchFinder;
};

// Vtype
struct _jc_soot_dava_toolkits_base_finders_SwitchFinder$vtype {
	_jc_type			type;
	_jc_soot_dava_toolkits_base_finders_SwitchFinder$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_dava_toolkits_base_finders_SwitchFinder$sub_refs {
	struct _jc_soot_util_IterableSet$object	*junkBody;
	struct _jc_java_util_HashSet$object	*targetSet;
	struct _jc_java_util_LinkedList$object	*targetList;
	struct _jc_java_util_LinkedList$object	*snTargetList;
	struct _jc_java_util_LinkedList$object	*tSuccList;
	struct _jc_java_util_HashMap$object	*index2target;
	struct _jc_java_util_HashMap$object	*tSucc2indexSet;
	struct _jc_java_util_HashMap$object	*tSucc2target;
	struct _jc_java_util_HashMap$object	*tSucc2Body;
};

// Reference instance fields (object)
struct _jc_soot_dava_toolkits_base_finders_SwitchFinder$refs {
    _jc_soot_dava_toolkits_base_finders_SwitchFinder$sub_refs	soot_dava_toolkits_base_finders_SwitchFinder;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_dava_toolkits_base_finders_SwitchFinder$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_dava_toolkits_base_finders_SwitchFinder$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_dava_toolkits_base_finders_SwitchFinder$sub_nonrefs	soot_dava_toolkits_base_finders_SwitchFinder;
};

// Object instance structure
struct _jc_soot_dava_toolkits_base_finders_SwitchFinder$object {
	_jc_soot_dava_toolkits_base_finders_SwitchFinder$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_dava_toolkits_base_finders_SwitchFinder$vtype	*vtype;
	_jc_soot_dava_toolkits_base_finders_SwitchFinder$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_dava_toolkits_base_finders_SwitchFinder$vtype _jc_soot_dava_toolkits_base_finders_SwitchFinder$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_dava_toolkits_base_finders_SwitchFinder, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_dava_toolkits_base_finders_SwitchFinder$class_object;

#endif	/* _JC_soot_dava_toolkits_base_finders_SwitchFinder_H_ */
